# bioio

[![Build Status](https://github.com/bioio-devs/bioio/actions/workflows/ci.yml/badge.svg)](https://github.com/bioio-devs/bioio/actions)
[![Documentation](https://github.com/bioio-devs/bioio/actions/workflows/docs.yml/badge.svg)](https://bioio-devs.github.io/bioio)

Image reading, metadata management, and image writing for Microscopy images in Python

---

## Installation

**Stable Release:** `pip install bioio`<br>
**Development Head:** `pip install git+https://github.com/bioio-devs/bioio.git`

## Quickstart

```python
from bioio import example

print(example.str_len("hello"))  # prints 5
```

## Documentation

For full package documentation please visit [bioio-devs.github.io/bioio](https://bioio-devs.github.io/bioio).

## Development

See [CONTRIBUTING.md](CONTRIBUTING.md) for information related to developing the code.

**BSD License**
